@@ -1,7 +1,11 @@
 require 'mkmf'
 require 'fileutils'
 
-$CFLAGS << ' -std=c99 -D_POSIX_C_SOURCE=200809L -Wall -Wextra -Werror'
+$CFLAGS << ' -std=c99 -D_POSIX_C_SOURCE=200809L -Wall -Wextra'
+
+if enable_config('fail-on-warning')
+  $CFLAGS << ' -Werrno'
+end
 
 if enable_config('debug')
   $CFLAGS << ' -O0 -g'
