@@ -1,11 +1,11 @@
+#include "mmap.h"
+
 #include <errno.h>
 #include <fcntl.h>
-#include <ruby.h>
 #include <ruby/util.h>
 #include <sys/mman.h>
 
 #include "file_format.h"
-#include "mmap.h"
 #include "utils.h"
 
 #if 0
@@ -257,7 +257,7 @@ VALUE mm_init(VALUE obj, VALUE fname) {
 
     if (reserve_mmap_file_bytes(fd, reserve_size) != 0) {
         close(fd);
-        rb_raise(rb_eIOError, "Can't reserve %zu bytes for memory-mapped file", reserve_size);
+        rb_raise(rb_eIOError, "Can't reserve %zu bytes for memory-mapped file in %s", reserve_size, path);
     }
 
     addr = mmap(0, size, pmode, vscope, fd, offset);
